@@ -5,11 +5,11 @@ function(base_hostname=NA,limit=20,offset=0,filter="HTML",
   if(!is.character(base_hostname))
     stop("base_hostname must be a string")
   
-  if(!is.numeric(limit) || (limit<=0 || limit>=21) )
-    stop("limit must be a numeric type beetwen 0 and 20 (inclusive")
+  if(!is.numeric(limit) || (limit<1 || limit>20) )
+    stop("limit must be a numeric type beetwen 1 and 20 (inclusive)")
   
-  if(!is.numeric(offset) || (offset<0 || offset>=21) )
-    stop("offset must be a numeric type greater or equal to limit")
+  if(!is.numeric(offset))
+    stop("offset must be a numeric type")
   
   filter_type<-c("HTML","text","raw")
   
@@ -39,7 +39,7 @@ function(base_hostname=NA,limit=20,offset=0,filter="HTML",
   
   bodyParams<-Params[s]
    
-  url<-paste("http://api.tumblr.com/v2/blog/",base_hostname,"/posts/queue",sep="")
+  url<-paste("https://api.tumblr.com/v2/blog/",base_hostname,"/posts/queue",sep="")
   connection<-"GET"
   
   res<-fromJSON(http.connection(url,token,bodyParams,consumer_key,consumer_secret,connection))
